@@ -18,15 +18,17 @@ class Secrets():
     mint_mfa_seed: str = None
 
 
-def loadSecrets():
+def _loadSecrets() -> dict:
     fileSecrets = {}
-    path = arg('config_file')
+    path = arg('secrets_file')
+    os.makedirs(os.path.dirname(path), exist_ok=True)
     if os.path.exists(path):
         with open(path) as file:
             try:
                 fileSecrets = json.load(file)
             except JSONDecodeError:
-                print(f'Error reading {file.name}; assuming it to be empty')
+                logger.warn(
+                    f'Error reading {file.name}; assuming it to be empty')
                 return {}
 
     for key in {
@@ -38,8 +40,16 @@ def loadSecrets():
     return fileSecrets
 
 
-def updateStash(key, value):
-    secrets = {**loadSecrets()}
+def updateStash(key, value) -> None:
+    secrets = {**_loadSecrets()}
+
+    if key not in secrets.keys():
+        secrets[key] = value
+
+    logger.debug(
+        'Secrets prior to update:\n'
+        f'{secrets}'
+    )
     if value == '':
         logger.info(
             f'Empty value for key: {key}. Maintaining current value: {secrets[key]}')  # noqa
@@ -47,9 +57,15 @@ def updateStash(key, value):
 
     logger.debug(f'Updating key: {key} to value: {value}')
     secrets[key] = value
-    with open(arg('config_file'), 'w+') as file:
+    with open(arg('secrets_file'), 'w+') as file:
         logger.debug('Persisting to disk...')
         file.write(json.dumps(secrets, indent=2))
+    secrets = {**_loadSecrets()}
+    logger.debug(
+        'Secrets after update:\n'
+        f'{secrets}'
+    )
 
 
-stash = Secrets(**loadSecrets())
+def get_stash() -> Secrets:
+    return Secrets(**_loadSecrets())
